@@ -1,8 +1,8 @@
-__version__ = "0.2.0"
+__version__ = "0.3.2"
 
 from .prover.SLDProver import SLDProver
 
-from .types import Atom, Constant, Predicate, Rule, Variable
+from .types import Atom, Constant, Predicate, Rule, Variable, Knowledge
 
 from .similarity import cosine_similarity, symbol_compare
 
@@ -11,6 +11,7 @@ __all__ = (
     "Atom",
     "Constant",
     "Predicate",
+    "Knowledge",
     "Rule",
     "Variable",
     "cosine_similarity",
