@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import Optional, Sequence
+from typing import Optional
 from fuzzy_reasoner.prover.Goal import Goal
 from fuzzy_reasoner.prover.ProofState import ProofState
 from fuzzy_reasoner.prover.operations.recurse import recurse
@@ -8,6 +8,7 @@ from fuzzy_reasoner.similarity import SimilarityFunc, cosine_similarity
 
 from fuzzy_reasoner.types.Atom import Atom
 from fuzzy_reasoner.prover.Proof import Proof
+from fuzzy_reasoner.types.Knowledge import Knowledge
 from fuzzy_reasoner.types.Rule import Rule
 
 
@@ -20,7 +21,7 @@ class SLDProver:
 
     def __init__(
         self,
-        rules: Sequence[Rule] = [],
+        knowledge: Knowledge = [],
         max_proof_depth: int = 10,
         min_similarity_threshold: float = 0.5,
         similarity_func: Optional[SimilarityFunc] = cosine_similarity,
@@ -28,23 +29,27 @@ class SLDProver:
         self.max_proof_depth = max_proof_depth
         self.min_similarity_threshold = min_similarity_threshold
         self.similarity_func = similarity_func
-        self.rules = frozenset(rules)
+        self.rules = process_knowledge(knowledge)
 
     def prove(
-        self, goal: Goal | Atom, dynamic_rules: Optional[Sequence[Rule]] = None
+        self, goal: Goal | Atom, extra_knowledge: Optional[Knowledge] = None
     ) -> Proof | None:
-        result_graphs = self.prove_all(goal, dynamic_rules)
+        result_graphs = self.prove_all(goal, extra_knowledge)
         return result_graphs[0] if len(result_graphs) > 0 else None
 
     def prove_all(
-        self, goal: Goal | Atom, dynamic_rules: Optional[Sequence[Rule]] = None
+        self, goal: Goal | Atom, extra_knowledge: Optional[Knowledge] = None
     ) -> list[Proof]:
         adjusted_goal = (
             goal
             if isinstance(goal, Goal)
             else Goal(goal, scope=generate_variable_scope())
         )
-        rules = self.rules.union(dynamic_rules) if dynamic_rules else self.rules
+        rules = (
+            self.rules.union(process_knowledge(extra_knowledge))
+            if extra_knowledge
+            else self.rules
+        )
         _successful_proof_states, successful_graph_nodes = recurse(
             adjusted_goal,
             self.max_proof_depth,
@@ -57,3 +62,9 @@ class SLDProver:
             return []
         graphs = [Proof(node) for node in successful_graph_nodes]
         return sorted(graphs, key=lambda graph: graph.similarity_score, reverse=True)
+
+
+def process_knowledge(knowledge: Knowledge) -> frozenset[Rule]:
+    return frozenset(
+        [item if isinstance(item, Rule) else Rule(item) for item in knowledge]
+    )
