@@ -3,11 +3,6 @@ from .Constant import Constant
 from .Predicate import Predicate
 from .Rule import Rule
 from .Variable import Variable
+from .Knowledge import Knowledge
 
-__all__ = (
-    "Atom",
-    "Constant",
-    "Predicate",
-    "Rule",
-    "Variable",
-)
+__all__ = ("Atom", "Constant", "Predicate", "Rule", "Variable", "Knowledge")
